#include "tiff.h"

void error(char *name);

void main (int argc, char **argv) 
{
  FILE *fp;
  struct TIFF_img input_img, output_img;
  int i,j,m,n;

  if ( argc != 3 ) error( argv[0] );

  /* open image file */
  if ( ( fp = fopen ( argv[1], "rb" ) ) == NULL ) {
    fprintf ( stderr, "cannot open file %s\n", argv[1] );
    exit ( 1 );
  }

  /* read image */
  if ( read_TIFF ( fp, &input_img ) ) {
    fprintf ( stderr, "error reading file %s\n", argv[1] );
    exit ( 1 );
  }

  /* close image file */
  fclose ( fp );

  /* check the type of image data */
  if ( input_img.TIFF_type != 'c' ) {
    fprintf ( stderr, "error:  image must be 24-bit color\n" );
    exit ( 1 );
  }

  /* set up structure for output image */
  get_TIFF ( &output_img, 4*input_img.height, 4*input_img.width, 'c' );

  /* pixel replication */
  for ( i = 0; i < input_img.height; i++ )
  for ( j = 0; j < input_img.width; j++ )
    for ( m = 0; m < 4; m++ )
    for ( n = 0; n < 4; n++ ) {
      output_img.color[0][4*i+m][4*j+n] = input_img.color[0][i][j];
      output_img.color[1][4*i+m][4*j+n] = input_img.color[1][i][j];
      output_img.color[2][4*i+m][4*j+n] = input_img.color[2][i][j];
    }

  /* open image file */
  if ( ( fp = fopen ( argv[2], "wb" ) ) == NULL ) {
    fprintf ( stderr, "cannot open file %s\n", argv[2] );
    exit ( 1 );
  }

  /* write image */
  if ( write_TIFF ( fp, &output_img ) ) {
    fprintf ( stderr, "error writing TIFF file %s\n", argv[2] );
    exit ( 1 );
  }

  /* close image file */
  fclose ( fp );

  /* de-allocate space which was used for the images */
  free_TIFF ( &(input_img) );
  free_TIFF ( &(output_img) );
}

void error(char *name)
{
    printf("usage:  %s  infile.tiff  outfile.tiff\n",name);
    printf("this program reads in a 24-bit color TIFF image,\n");
    printf("pixel replicates it by a factor of 4,\n");
    printf("then writes out the resulting image.\n");
    exit(1);
}

